@@ -132,6 +132,10 @@ fn default_pairhmm_mode() -> String {
     "exact".to_owned()
 }
 
+fn default_log_mode() -> String {
+    "default".to_owned()
+}
+
 fn default_min_bam_refetch_distance() -> u64 {
     1
 }
@@ -271,6 +275,16 @@ pub enum PreprocessKind {
         )]
         #[serde(default = "default_pairhmm_mode")]
         pairhmm_mode: String,
+        #[structopt(
+            long = "log-mode",
+            possible_values = &["default", "each-record"],
+            default_value = "default",
+            help = "Specify how progress should be logged. By default, a record count will be printed. With 'each-record', \
+            Varlociraptor will additionally print contig and position of each processed candidate variant record. This is \
+            useful for debugging."
+        )]
+        #[serde(default = "default_log_mode")]
+        log_mode: String,
     },
 }
 
@@ -638,6 +652,7 @@ pub fn run(opt: Varlociraptor) -> Result<()> {
                     reference_buffer_size,
                     min_bam_refetch_distance,
                     pairhmm_mode,
+                    log_mode,
                 } => {
                     // TODO: handle testcases
 
@@ -676,9 +691,16 @@ pub fn run(opt: Varlociraptor) -> Result<()> {
                         reference_buffer_size,
                     ));
 
+                    let log_each_record = if log_mode == "each-record" {
+                        true
+                    } else {
+                        false
+                    };
+
                     if pairhmm_mode == "fast" {
                         let mut processor =
                             calling::variants::preprocessing::ObservationProcessor::builder()
+                                .log_each_record(log_each_record)
                                 .alignment_properties(alignment_properties)
                                 .protocol_strandedness(protocol_strandedness)
                                 .max_depth(max_depth)
@@ -715,6 +737,7 @@ pub fn run(opt: Varlociraptor) -> Result<()> {
                                     gap_params,
                                     realignment_window,
                                 ))
+                                .log_each_record(log_each_record)
                                 .build();
 
                         processor.process()?;
