@@ -5,6 +5,7 @@
 
 use std::cell::RefCell;
 use std::cmp;
+use std::ops::Range;
 use std::rc::Rc;
 use std::sync::Arc;
 
@@ -308,6 +309,10 @@ impl<'a> RefBaseEmission for DeletionEmissionParams<'a> {
         }
     }
 
+    fn variant_ref_range(&self) -> Option<Range<usize>> {
+        Some(self.del_start..self.del_start + self.del_len)
+    }
+
     default_ref_base_emission!();
 }
 
